#include <RTI/Handle.h>
#include <limits.h>
#include <sstream>
#include "RTI1516HandleImplementation.h"

namespace rti1516
{

	/* Constructs an invalid handle                           */ 
	HandleImplementation::HandleImplementation()                                                   
	: _value(ULONG_MAX)                                          
	{                                                            
	}                                                            
	                                                             
	HandleImplementation::HandleImplementation(VariableLengthData const & encodedValue)            
	: _value(ULONG_MAX)                                          
	{                                                            
		                                                         
	}                                                            
	                                                             
	HandleImplementation::~HandleImplementation()                                                  
	throw()                                                      
	{                                                            
	}                                                            
	                                                             
	HandleImplementation::HandleImplementation(HandleImplementation const & rhs)                                    
	: _value(ULONG_MAX)                                          
	{                                                            
		_value = rhs._value;                                     
	}                                                            
	                                                             
	HandleImplementation & HandleImplementation::operator=(HandleImplementation const & rhs)                        
	{                                                            
		if (this != &rhs)                                        
		{                                                        
			_value = rhs._value;                                 
		}                                                        
		return *this;                                            
	}                                                            
	                                                             
	/* Indicates whether this handle is valid                 */ 
	bool HandleImplementation::isValid() const                                    
	{                                                            
		if (_value == ULONG_MAX)                                 
			return false;                                        
		else                                                     
			return true;                                         
	}															 
	                                                             
	/* All invalid handles are equivalent                     */ 
	bool HandleImplementation::operator==(HandleImplementation const & rhs) const                  
	{                                                            
		return _value == rhs._value;                             
	}                                                            
	bool HandleImplementation::operator!=(HandleImplementation const & rhs) const                  
	{                                                            
		return _value != rhs._value;                             
	}                                                            
	bool HandleImplementation::operator< (HandleImplementation const & rhs) const                  
	{                                                            
		return _value < rhs._value;                              
	}                                                            
	                                                             
	/* Generate an encoded value that can be used to send     */ 
	/* handles to other federates in updates or interactions. */ 
	VariableLengthData HandleImplementation::encode() const                       
	{                                                            
		unsigned char buf[sizeof(_value)];                       
		encode(buf, sizeof(_value));                             
		VariableLengthData c(buf, sizeof(_value));               
		return c;                                                
	}                                                            
	                                                             
	/* Alternate encode for directly filling a buffer         */ 
	unsigned long HandleImplementation::encodedLength() const                     
	{                                                            
	    return sizeof(_value);                                   
	}                                                            
	unsigned long HandleImplementation::encode(                                   
	void* buffer, unsigned long bufferSize) const                
	throw (CouldNotEncode)                                       
	{                                                            
	    if (bufferSize < sizeof(_value))                         
			throw CouldNotEncode(L"Not enough room in buffer to encode handle"); 
	                                                             
		unsigned long val = _value;                              
		char *buf = (char *) buffer;                             
		for(int i = 0; i < sizeof(_value); i++)                  
		{                                                        
			buf[sizeof(_value)-i] = (char) val & 0xFF;           
			val = val >> 1;                                      
		}                                                        
		return sizeof(_value);                                   
	}                                                            
	                                                             
	std::wstring HandleImplementation::toString() const                           
	{                                                            
		std::wostringstream ost;                                 
		ost << _value;                                           
		return ost.str();                                        
	}                                                            



#define DECLARE_HANDLE_IMPLEMENTATION_CLASS(HIK)                 \
	                                                             \
	/* Constructs an invalid handle                           */ \
	HIK::HIK()                                                   \
	: HandleImplementation()                                          \
	{                                                            \
	}                                                            \
	                                                             \
	HIK::HIK(VariableLengthData const & encodedValue)            \
	: HandleImplementation(encodedValue)                                          \
	{                                                            \
		                                                         \
	}                                                            \
	                                                             \
	HIK::~HIK()                                                  \
	throw()                                                      \
	{                                                            \
	}                                                            \
	                                                             \
	HIK::HIK(HIK const & rhs)                                    \
	: HandleImplementation(rhs)                                          \
	{                                                            \
		_value = rhs._value;                                     \
	}                                                            \
	                                                             \
	HIK & HIK::operator=(HIK const & rhs)                        \
	{                                                            \
		if (this != &rhs)                                        \
		{                                                        \
			_value = rhs._value;                                 \
		}                                                        \
		return *this;                                            \
	}                                                            \
	                                                             \
	/* Indicates whether this handle is valid                 */ \
	bool HIK::isValid() const                                    \
	{                                                            \
		if (_value == ULONG_MAX)                                 \
			return false;                                        \
		else                                                     \
			return true;                                         \
	}															 \
	                                                             \
	/* All invalid handles are equivalent                     */ \
	bool HIK::operator==(HIK const & rhs) const                  \
	{                                                            \
		return _value == rhs._value;                             \
	}                                                            \
	bool HIK::operator!=(HIK const & rhs) const                  \
	{                                                            \
		return _value != rhs._value;                             \
	}                                                            \
	bool HIK::operator< (HIK const & rhs) const                  \
	{                                                            \
		return _value < rhs._value;                              \
	}                                                            \
	                                                             \
	/* Generate an encoded value that can be used to send     */ \
	/* handles to other federates in updates or interactions. */ \
	VariableLengthData HIK::encode() const                       \
	{                                                            \
		unsigned char buf[sizeof(_value)];                       \
		encode(buf, sizeof(_value));                             \
		VariableLengthData c(buf, sizeof(_value));               \
		return c;                                                \
	}                                                            \
	                                                             \
	/* Alternate encode for directly filling a buffer         */ \
	unsigned long HIK::encodedLength() const                     \
	{                                                            \
	    return sizeof(_value);                                   \
	}                                                            \
	unsigned long HIK::encode(                                   \
	void* buffer, unsigned long bufferSize) const                \
	throw (CouldNotEncode)                                       \
	{                                                            \
	    if (bufferSize < sizeof(_value))                         \
			throw CouldNotEncode(L"Not enough room in buffer to encode handle"); \
	                                                             \
		unsigned long val = _value;                              \
		char *buf = (char *) buffer;                             \
		for(int i = 0; i < sizeof(_value); i++)                  \
		{                                                        \
			buf[sizeof(_value)-i] = (char) val & 0xFF;           \
			val = val >> 1;                                      \
		}                                                        \
		return sizeof(_value);                                   \
	}                                                            \
	                                                             \
	std::wstring HIK::toString() const                           \
	{                                                            \
		std::wostringstream ost;                                 \
		ost << _value;                                           \
		return ost.str();                                        \
	}                                                            \
	/* end DECLARE_HANDLE_IMPLEMENTATION_CLASS */


DECLARE_HANDLE_IMPLEMENTATION_CLASS(FederateHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(ObjectClassHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(InteractionClassHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(ObjectInstanceHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(AttributeHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(ParameterHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(DimensionHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(MessageRetractionHandleImplementation)
DECLARE_HANDLE_IMPLEMENTATION_CLASS(RegionHandleImplementation)


} // end namespace rti1516
