#include "RTI1516ambassador.h"
#include <RTI/RangeBounds.h>

#include "PrettyDebug.hh"

#include "M_Classes.hh"

namespace {

static PrettyDebug D("LIBRTI", __FILE__);
static PrettyDebug G("GENDOC",__FILE__) ;

}

namespace rti1516
{
	RTIambassador::RTIambassador()
	{
	}

	RTIambassador::~RTIambassador()
	{
	}


	RTI1516ambassador::RTI1516ambassador() throw()
		: privateRefs(0)
	{
	}

	RTI1516ambassador::~RTI1516ambassador()
	{
		certi::M_Close_Connexion req, rep ;

		G.Out(pdGendoc,"        ====>executeService CLOSE_CONNEXION");
		privateRefs->executeService(&req, &rep);
		// after the response is received, the privateRefs->socketUn must not be used

		delete privateRefs;
	}

	// 4.2
	void RTI1516ambassador::createFederationExecution
		(std::wstring const & federationExecutionName,
		std::wstring const & fullPathNameToTheFDDfile,
		std::wstring const & logicalTimeImplementationName)
		throw (FederationExecutionAlreadyExists,
		CouldNotOpenFDD,
		ErrorReadingFDD,
		CouldNotCreateLogicalTimeFactory,
		RTIinternalError)
	{ 
		/* TODO */
		certi::M_Create_Federation_Execution req, rep ;

		G.Out(pdGendoc,"enter RTIambassador::createFederationExecution");
		std::string federationExecutionNameAsString(federationExecutionName.begin(), federationExecutionName.end());
		req.setFederationName(federationExecutionNameAsString);
		
		std::string fullPathNameToTheFDDfileAsString(fullPathNameToTheFDDfile.begin(), fullPathNameToTheFDDfile.end());
		req.setFEDid(fullPathNameToTheFDDfileAsString);

		/*#ifdef _WIN32
		if(!stricmp(FED,executionName)) {
		#else
		if(!strcasecmp(FED,exeName)) {
		#endif
		}*/
		G.Out(pdGendoc,"             ====>executeService CREATE_FEDERATION_EXECUTION");

		privateRefs->executeService(&req, &rep);

		G.Out(pdGendoc,"exit RTIambassador::createFederationExecution");

		// TODO What to do with the 'logicalTimeImplementationName'? Can't find it's use in SISO-STD-004.1-2004
		// Only exists in C++ interface.
		// Ignored for now.
	}

	// 4.3
	void RTI1516ambassador::destroyFederationExecution 
		(std::wstring const & federationExecutionName)
		throw (FederatesCurrentlyJoined,
		FederationExecutionDoesNotExist,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.4
	FederateHandle RTI1516ambassador::joinFederationExecution 
		(std::wstring const & federateType,
		std::wstring const & federationExecutionName,
		FederateAmbassador & federateAmbassador)
		throw (FederateAlreadyExecutionMember,
		FederationExecutionDoesNotExist,
		SaveInProgress,
		RestoreInProgress,
		CouldNotCreateLogicalTimeFactory,
		RTIinternalError)
	{ 
		/* TODO */ 
		FederateHandle invalidHandle;

		return invalidHandle;
	}

	// 4.5
	void RTI1516ambassador::resignFederationExecution
		(ResignAction resignAction)
		throw (OwnershipAcquisitionPending,
		FederateOwnsAttributes,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.6
	void RTI1516ambassador::registerFederationSynchronizationPoint
		(std::wstring const & label,
		VariableLengthData const & theUserSuppliedTag)
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	void RTI1516ambassador::registerFederationSynchronizationPoint
		(std::wstring const & label,
		VariableLengthData const & theUserSuppliedTag,
		FederateHandleSet const & syncSet)
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.9
	void RTI1516ambassador::synchronizationPointAchieved
		(std::wstring const & label)
		throw (SynchronizationPointLabelNotAnnounced,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.11
	void RTI1516ambassador::requestFederationSave
		(std::wstring const & label)
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	void RTI1516ambassador::requestFederationSave
		(std::wstring const & label,
		LogicalTime const & theTime)
		throw (LogicalTimeAlreadyPassed,
		InvalidLogicalTime,
		FederateUnableToUseTime,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.13
	void RTI1516ambassador::federateSaveBegun ()
		throw (SaveNotInitiated,
		FederateNotExecutionMember,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.14
	void RTI1516ambassador::federateSaveComplete ()
		throw (FederateHasNotBegunSave,
		FederateNotExecutionMember,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	void RTI1516ambassador::federateSaveNotComplete()
		throw (FederateHasNotBegunSave,
		FederateNotExecutionMember,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.16
	void RTI1516ambassador::queryFederationSaveStatus ()
		throw (FederateNotExecutionMember,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.18
	void RTI1516ambassador::requestFederationRestore
		(std::wstring const & label)
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.22
	void RTI1516ambassador::federateRestoreComplete ()
		throw (RestoreNotRequested,
		FederateNotExecutionMember,
		SaveInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	void RTI1516ambassador::federateRestoreNotComplete ()
		throw (RestoreNotRequested,
		FederateNotExecutionMember,
		SaveInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 4.24
	void RTI1516ambassador::queryFederationRestoreStatus ()
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	/////////////////////////////////////
	// Declaration Management Services //
	/////////////////////////////////////

	// 5.2
	void RTI1516ambassador::publishObjectClassAttributes
		(ObjectClassHandle theClass,
		AttributeHandleSet const & attributeList)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 5.3
	void RTI1516ambassador::unpublishObjectClass
		(ObjectClassHandle theClass)
		throw (ObjectClassNotDefined,
		OwnershipAcquisitionPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	void RTI1516ambassador::unpublishObjectClassAttributes
		(ObjectClassHandle theClass,
		AttributeHandleSet const & attributeList)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		OwnershipAcquisitionPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 5.4
	void RTI1516ambassador::publishInteractionClass
		(InteractionClassHandle theInteraction)
		throw (InteractionClassNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 5.5
	void RTI1516ambassador::unpublishInteractionClass
		(InteractionClassHandle theInteraction)
		throw (InteractionClassNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 5.6
	void RTI1516ambassador::subscribeObjectClassAttributes
		(ObjectClassHandle theClass,
		AttributeHandleSet const & attributeList,
		bool active)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 5.7
	void RTI1516ambassador::unsubscribeObjectClass
		(ObjectClassHandle theClass)
		throw (ObjectClassNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	void RTI1516ambassador::unsubscribeObjectClassAttributes
		(ObjectClassHandle theClass,
		AttributeHandleSet const & attributeList)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 5.8
	void RTI1516ambassador::subscribeInteractionClass
		(InteractionClassHandle theClass,
		bool active)
		throw (InteractionClassNotDefined,
		FederateServiceInvocationsAreBeingReportedViaMOM,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 5.9
	void RTI1516ambassador::unsubscribeInteractionClass
		(InteractionClassHandle theClass)
		throw (InteractionClassNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	////////////////////////////////
	// Object Management Services //
	////////////////////////////////

	// 6.2
	void RTI1516ambassador::reserveObjectInstanceName
		(std::wstring const & theObjectInstanceName)
		throw (IllegalName,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 6.4
	ObjectInstanceHandle RTI1516ambassador::registerObjectInstance
		(ObjectClassHandle theClass)
		throw (ObjectClassNotDefined,
		ObjectClassNotPublished,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		ObjectInstanceHandle invalidHandle;

		return invalidHandle;
	}

	ObjectInstanceHandle RTI1516ambassador::registerObjectInstance
		(ObjectClassHandle theClass,
		std::wstring const & theObjectInstanceName)
		throw (ObjectClassNotDefined,
		ObjectClassNotPublished,
		ObjectInstanceNameNotReserved,
		ObjectInstanceNameInUse,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		ObjectInstanceHandle invalidHandle;

		return invalidHandle;
	}

	// 6.6
	void RTI1516ambassador::updateAttributeValues
		(ObjectInstanceHandle theObject,
		AttributeHandleValueMap const & theAttributeValues,
		VariableLengthData const & theUserSuppliedTag)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	MessageRetractionHandle RTI1516ambassador::updateAttributeValues
		(ObjectInstanceHandle theObject,
		AttributeHandleValueMap const & theAttributeValues,
		VariableLengthData const & theUserSuppliedTag,
		LogicalTime const & theTime)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		InvalidLogicalTime,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		MessageRetractionHandle invalidHandle;

		return invalidHandle;
	}

	// 6.8
	void RTI1516ambassador::sendInteraction
		(InteractionClassHandle theInteraction,
		ParameterHandleValueMap const & theParameterValues,
		VariableLengthData const & theUserSuppliedTag)
		throw (InteractionClassNotPublished,
		InteractionClassNotDefined,
		InteractionParameterNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	MessageRetractionHandle RTI1516ambassador::sendInteraction
		(InteractionClassHandle theInteraction,
		ParameterHandleValueMap const & theParameterValues,
		VariableLengthData const & theUserSuppliedTag,
		LogicalTime const & theTime)
		throw (InteractionClassNotPublished,
		InteractionClassNotDefined,
		InteractionParameterNotDefined,
		InvalidLogicalTime,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		MessageRetractionHandle invalidHandle;

		return invalidHandle;
	}

	// 6.10
	void RTI1516ambassador::deleteObjectInstance
		(ObjectInstanceHandle theObject,
		VariableLengthData const & theUserSuppliedTag)
		throw (DeletePrivilegeNotHeld,
		ObjectInstanceNotKnown,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	MessageRetractionHandle RTI1516ambassador::deleteObjectInstance
		(ObjectInstanceHandle theObject,
		VariableLengthData const & theUserSuppliedTag,
		LogicalTime  const & theTime)
		throw (DeletePrivilegeNotHeld,
		ObjectInstanceNotKnown,
		InvalidLogicalTime,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		MessageRetractionHandle invalidHandle;

		return invalidHandle;
	}

	// 6.12
	void RTI1516ambassador::localDeleteObjectInstance
		(ObjectInstanceHandle theObject)
		throw (ObjectInstanceNotKnown,
		FederateOwnsAttributes,
		OwnershipAcquisitionPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 6.13
	void RTI1516ambassador::changeAttributeTransportationType
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes,
		TransportationType theType)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 6.14
	void RTI1516ambassador::changeInteractionTransportationType
		(InteractionClassHandle theClass,
		TransportationType theType)
		throw (InteractionClassNotDefined,
		InteractionClassNotPublished,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 6.17
	void RTI1516ambassador::requestAttributeValueUpdate
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes,
		VariableLengthData const & theUserSuppliedTag)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	void RTI1516ambassador::requestAttributeValueUpdate
		(ObjectClassHandle theClass,
		AttributeHandleSet const & theAttributes,
		VariableLengthData const & theUserSuppliedTag)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	///////////////////////////////////
	// Ownership Management Services //
	///////////////////////////////////
	// 7.2
	void RTI1516ambassador::unconditionalAttributeOwnershipDivestiture
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.3
	void RTI1516ambassador::negotiatedAttributeOwnershipDivestiture
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes,
		VariableLengthData const & theUserSuppliedTag)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		AttributeAlreadyBeingDivested,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.6
	void RTI1516ambassador::confirmDivestiture
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & confirmedAttributes,
		VariableLengthData const & theUserSuppliedTag)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		AttributeDivestitureWasNotRequested,
		NoAcquisitionPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.8
	void RTI1516ambassador::attributeOwnershipAcquisition
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & desiredAttributes,
		VariableLengthData const & theUserSuppliedTag)
		throw (ObjectInstanceNotKnown,
		ObjectClassNotPublished,
		AttributeNotDefined,
		AttributeNotPublished,
		FederateOwnsAttributes,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.9
	void RTI1516ambassador::attributeOwnershipAcquisitionIfAvailable
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & desiredAttributes)
		throw (ObjectInstanceNotKnown,
		ObjectClassNotPublished,
		AttributeNotDefined,
		AttributeNotPublished,
		FederateOwnsAttributes,
		AttributeAlreadyBeingAcquired,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.12
	void RTI1516ambassador::attributeOwnershipDivestitureIfWanted
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes,
		AttributeHandleSet & theDivestedAttributes) // filled by RTI
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.13
	void RTI1516ambassador::cancelNegotiatedAttributeOwnershipDivestiture
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		AttributeDivestitureWasNotRequested,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.14
	void RTI1516ambassador::cancelAttributeOwnershipAcquisition
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeAlreadyOwned,
		AttributeAcquisitionWasNotRequested,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.16
	void RTI1516ambassador::queryAttributeOwnership
		(ObjectInstanceHandle theObject,
		AttributeHandle theAttribute)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 7.18
	bool RTI1516ambassador::isAttributeOwnedByFederate
		(ObjectInstanceHandle theObject,
		AttributeHandle theAttribute)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */

		throw RTIinternalError(L"Not yet implemented");
	}

	//////////////////////////////
	// Time Management Services //
	//////////////////////////////

	// 8.2
	void RTI1516ambassador::enableTimeRegulation
		(LogicalTimeInterval const & theLookahead)
		throw (TimeRegulationAlreadyEnabled,
		InvalidLookahead,
		InTimeAdvancingState,
		RequestForTimeRegulationPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.4
	void RTI1516ambassador::disableTimeRegulation ()
		throw (TimeRegulationIsNotEnabled,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.5
	void RTI1516ambassador::enableTimeConstrained ()
		throw (TimeConstrainedAlreadyEnabled,
		InTimeAdvancingState,
		RequestForTimeConstrainedPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.7
	void RTI1516ambassador::disableTimeConstrained ()
		throw (TimeConstrainedIsNotEnabled,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.8
	void RTI1516ambassador::timeAdvanceRequest
		(LogicalTime const & theTime)
		throw (InvalidLogicalTime,
		LogicalTimeAlreadyPassed,
		InTimeAdvancingState,
		RequestForTimeRegulationPending,
		RequestForTimeConstrainedPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.9
	void RTI1516ambassador::timeAdvanceRequestAvailable
		(LogicalTime const & theTime)
		throw (InvalidLogicalTime,
		LogicalTimeAlreadyPassed,
		InTimeAdvancingState,
		RequestForTimeRegulationPending,
		RequestForTimeConstrainedPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.10
	void RTI1516ambassador::nextMessageRequest
		(LogicalTime const & theTime)
		throw (InvalidLogicalTime,
		LogicalTimeAlreadyPassed,
		InTimeAdvancingState,
		RequestForTimeRegulationPending,
		RequestForTimeConstrainedPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.11
	void RTI1516ambassador::nextMessageRequestAvailable
		(LogicalTime const & theTime)
		throw (InvalidLogicalTime,
		LogicalTimeAlreadyPassed,
		InTimeAdvancingState,
		RequestForTimeRegulationPending,
		RequestForTimeConstrainedPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.12
	void RTI1516ambassador::flushQueueRequest
		(LogicalTime const & theTime)
		throw (InvalidLogicalTime,
		LogicalTimeAlreadyPassed,
		InTimeAdvancingState,
		RequestForTimeRegulationPending,
		RequestForTimeConstrainedPending,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.14
	void RTI1516ambassador::enableAsynchronousDelivery ()
		throw (AsynchronousDeliveryAlreadyEnabled,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.15
	void RTI1516ambassador::disableAsynchronousDelivery ()
		throw (AsynchronousDeliveryAlreadyDisabled,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.16
	bool RTI1516ambassador::queryGALT (LogicalTime & theTime)
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 8.17
	void RTI1516ambassador::queryLogicalTime (LogicalTime & theTime)
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.18
	bool RTI1516ambassador::queryLITS (LogicalTime & theTime)
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 8.19
	void RTI1516ambassador::modifyLookahead
		(LogicalTimeInterval const & theLookahead)
		throw (TimeRegulationIsNotEnabled,
		InvalidLookahead,
		InTimeAdvancingState,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.20
	void RTI1516ambassador::queryLookahead (LogicalTimeInterval & interval)
		throw (TimeRegulationIsNotEnabled,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.21
	void RTI1516ambassador::retract
		(MessageRetractionHandle theHandle)
		throw (InvalidRetractionHandle,
		TimeRegulationIsNotEnabled,
		MessageCanNoLongerBeRetracted,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.23
	void RTI1516ambassador::changeAttributeOrderType
		(ObjectInstanceHandle theObject,
		AttributeHandleSet const & theAttributes,
		OrderType theType)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		AttributeNotOwned,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 8.24
	void RTI1516ambassador::changeInteractionOrderType
		(InteractionClassHandle theClass,
		OrderType theType)
		throw (InteractionClassNotDefined,
		InteractionClassNotPublished,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	//////////////////////////////////
	// Data Distribution Management //
	//////////////////////////////////

	// 9.2
	RegionHandle RTI1516ambassador::createRegion
		(DimensionHandleSet const & theDimensions)
		throw (InvalidDimensionHandle,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 9.3
	void RTI1516ambassador::commitRegionModifications
		(RegionHandleSet const & theRegionHandleSet)
		throw (InvalidRegion,
		RegionNotCreatedByThisFederate,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.4
	void RTI1516ambassador::deleteRegion
		(RegionHandle theRegion)
		throw (InvalidRegion,
		RegionNotCreatedByThisFederate,
		RegionInUseForUpdateOrSubscription,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.5
	ObjectInstanceHandle RTI1516ambassador::registerObjectInstanceWithRegions
		(ObjectClassHandle theClass,
		AttributeHandleSetRegionHandleSetPairVector const &
		theAttributeHandleSetRegionHandleSetPairVector)
		throw (ObjectClassNotDefined,
		ObjectClassNotPublished,
		AttributeNotDefined,
		AttributeNotPublished,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	ObjectInstanceHandle RTI1516ambassador::registerObjectInstanceWithRegions
		(ObjectClassHandle theClass,
		AttributeHandleSetRegionHandleSetPairVector const &
		theAttributeHandleSetRegionHandleSetPairVector,
		std::wstring const & theObjectInstanceName)
		throw (ObjectClassNotDefined,
		ObjectClassNotPublished,
		AttributeNotDefined,
		AttributeNotPublished,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		ObjectInstanceNameNotReserved,
		ObjectInstanceNameInUse,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 9.6
	void RTI1516ambassador::associateRegionsForUpdates
		(ObjectInstanceHandle theObject,
		AttributeHandleSetRegionHandleSetPairVector const &
		theAttributeHandleSetRegionHandleSetPairVector)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.7
	void RTI1516ambassador::unassociateRegionsForUpdates
		(ObjectInstanceHandle theObject,
		AttributeHandleSetRegionHandleSetPairVector const &
		theAttributeHandleSetRegionHandleSetPairVector)
		throw (ObjectInstanceNotKnown,
		AttributeNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.8
	void RTI1516ambassador::subscribeObjectClassAttributesWithRegions
		(ObjectClassHandle theClass,
		AttributeHandleSetRegionHandleSetPairVector const &
		theAttributeHandleSetRegionHandleSetPairVector,
		bool active)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.9
	void RTI1516ambassador::unsubscribeObjectClassAttributesWithRegions
		(ObjectClassHandle theClass,
		AttributeHandleSetRegionHandleSetPairVector const &
		theAttributeHandleSetRegionHandleSetPairVector)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.10
	void RTI1516ambassador::subscribeInteractionClassWithRegions
		(InteractionClassHandle theClass,
		RegionHandleSet const & theRegionHandleSet,
		bool active)
		throw (InteractionClassNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		FederateServiceInvocationsAreBeingReportedViaMOM,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.11
	void RTI1516ambassador::unsubscribeInteractionClassWithRegions
		(InteractionClassHandle theClass,
		RegionHandleSet const & theRegionHandleSet)
		throw (InteractionClassNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 9.12
	void RTI1516ambassador::sendInteractionWithRegions
		(InteractionClassHandle theInteraction,
		ParameterHandleValueMap const & theParameterValues,
		RegionHandleSet const & theRegionHandleSet,
		VariableLengthData const & theUserSuppliedTag)
		throw (InteractionClassNotDefined,
		InteractionClassNotPublished,
		InteractionParameterNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	MessageRetractionHandle RTI1516ambassador::sendInteractionWithRegions
		(InteractionClassHandle theInteraction,
		ParameterHandleValueMap const & theParameterValues,
		RegionHandleSet const & theRegionHandleSet,
		VariableLengthData const & theUserSuppliedTag,
		LogicalTime const & theTime)
		throw (InteractionClassNotDefined,
		InteractionClassNotPublished,
		InteractionParameterNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		InvalidLogicalTime,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 9.13
	void RTI1516ambassador::requestAttributeValueUpdateWithRegions
		(ObjectClassHandle theClass,
		AttributeHandleSetRegionHandleSetPairVector const & theSet,
		VariableLengthData const & theUserSuppliedTag)
		throw (ObjectClassNotDefined,
		AttributeNotDefined,
		InvalidRegion,
		RegionNotCreatedByThisFederate,
		InvalidRegionContext,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	//////////////////////////
	// RTI Support Services //
	//////////////////////////

	// 10.2
	ObjectClassHandle RTI1516ambassador::getObjectClassHandle
		(std::wstring const & theName)
		throw (NameNotFound,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.3
	std::wstring RTI1516ambassador::getObjectClassName
		(ObjectClassHandle theHandle)
		throw (InvalidObjectClassHandle,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.4
	AttributeHandle RTI1516ambassador::getAttributeHandle
		(ObjectClassHandle whichClass,
		std::wstring const & theAttributeName)
		throw (InvalidObjectClassHandle,
		NameNotFound,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.5
	std::wstring RTI1516ambassador::getAttributeName
		(ObjectClassHandle whichClass,
		AttributeHandle theHandle)   
		throw (InvalidObjectClassHandle,
		InvalidAttributeHandle,
		AttributeNotDefined,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.6
	InteractionClassHandle RTI1516ambassador::getInteractionClassHandle
		(std::wstring const & theName)
		throw (NameNotFound,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.7
	std::wstring RTI1516ambassador::getInteractionClassName
		(InteractionClassHandle theHandle)
		throw (InvalidInteractionClassHandle,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.8
	ParameterHandle RTI1516ambassador::getParameterHandle
		(InteractionClassHandle whichClass,
		std::wstring const & theName)
		throw (InvalidInteractionClassHandle,
		NameNotFound,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.9
	std::wstring RTI1516ambassador::getParameterName
		(InteractionClassHandle whichClass,
		ParameterHandle theHandle)   
		throw (InvalidInteractionClassHandle,
		InvalidParameterHandle,
		InteractionParameterNotDefined,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.10
	ObjectInstanceHandle RTI1516ambassador::getObjectInstanceHandle
		(std::wstring const & theName)
		throw (ObjectInstanceNotKnown,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.11
	std::wstring RTI1516ambassador::getObjectInstanceName
		(ObjectInstanceHandle theHandle)
		throw (ObjectInstanceNotKnown,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.12
	DimensionHandle RTI1516ambassador::getDimensionHandle
		(std::wstring const & theName)
		throw (NameNotFound,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.13
	std::wstring RTI1516ambassador::getDimensionName
		(DimensionHandle theHandle)
		throw (InvalidDimensionHandle,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.14
	unsigned long RTI1516ambassador::getDimensionUpperBound
		(DimensionHandle theHandle)   
		throw (InvalidDimensionHandle,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.15
	DimensionHandleSet RTI1516ambassador::getAvailableDimensionsForClassAttribute
		(ObjectClassHandle theClass,
		AttributeHandle theHandle)   
		throw (InvalidObjectClassHandle,
		InvalidAttributeHandle,
		AttributeNotDefined,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.16
	ObjectClassHandle RTI1516ambassador::getKnownObjectClassHandle
		(ObjectInstanceHandle theObject)
		throw (ObjectInstanceNotKnown,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.17
	DimensionHandleSet RTI1516ambassador::getAvailableDimensionsForInteractionClass
		(InteractionClassHandle theClass)
		throw (InvalidInteractionClassHandle,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.18
	TransportationType RTI1516ambassador::getTransportationType
		(std::wstring const & transportationName)
		throw (InvalidTransportationName,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.19
	std::wstring RTI1516ambassador::getTransportationName
		(TransportationType transportationType)
		throw (InvalidTransportationType,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.20
	OrderType RTI1516ambassador::getOrderType
		(std::wstring const & orderName)
		throw (InvalidOrderName,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.21
	std::wstring RTI1516ambassador::getOrderName
		(OrderType orderType)
		throw (InvalidOrderType,
		FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.22
	void RTI1516ambassador::enableObjectClassRelevanceAdvisorySwitch ()
		throw (ObjectClassRelevanceAdvisorySwitchIsOn,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.23
	void RTI1516ambassador::disableObjectClassRelevanceAdvisorySwitch ()
		throw (ObjectClassRelevanceAdvisorySwitchIsOff,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.24
	void RTI1516ambassador::enableAttributeRelevanceAdvisorySwitch ()
		throw (AttributeRelevanceAdvisorySwitchIsOn,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.25
	void RTI1516ambassador::disableAttributeRelevanceAdvisorySwitch ()
		throw (AttributeRelevanceAdvisorySwitchIsOff,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.26
	void RTI1516ambassador::enableAttributeScopeAdvisorySwitch ()
		throw (AttributeScopeAdvisorySwitchIsOn,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.27
	void RTI1516ambassador::disableAttributeScopeAdvisorySwitch ()
		throw (AttributeScopeAdvisorySwitchIsOff,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.28
	void RTI1516ambassador::enableInteractionRelevanceAdvisorySwitch ()
		throw (InteractionRelevanceAdvisorySwitchIsOn,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.29
	void RTI1516ambassador::disableInteractionRelevanceAdvisorySwitch ()
		throw (InteractionRelevanceAdvisorySwitchIsOff,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.30

	DimensionHandleSet RTI1516ambassador::getDimensionHandleSet
		(RegionHandle theRegionHandle)
		throw (InvalidRegion,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.31

	RangeBounds RTI1516ambassador::getRangeBounds
		(RegionHandle theRegionHandle,
		DimensionHandle theDimensionHandle)
		throw (InvalidRegion,
		RegionDoesNotContainSpecifiedDimension,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.32
	void RTI1516ambassador::setRangeBounds
		(RegionHandle theRegionHandle,
		DimensionHandle theDimensionHandle,
		RangeBounds const & theRangeBounds)
		throw (InvalidRegion,
		RegionNotCreatedByThisFederate,
		RegionDoesNotContainSpecifiedDimension,
		InvalidRangeBound,
		FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.33
	unsigned long RTI1516ambassador::normalizeFederateHandle
		(FederateHandle theFederateHandle)
		throw (FederateNotExecutionMember,
		InvalidFederateHandle,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.34
	unsigned long RTI1516ambassador::normalizeServiceGroup
		(ServiceGroupIndicator theServiceGroup)
		throw (FederateNotExecutionMember,
		InvalidServiceGroup,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.37
	bool RTI1516ambassador::evokeCallback(double approximateMinimumTimeInSeconds)
		throw (FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.38
	bool RTI1516ambassador::evokeMultipleCallbacks(double approximateMinimumTimeInSeconds,
		double approximateMaximumTimeInSeconds)
		throw (FederateNotExecutionMember,
		RTIinternalError)
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	// 10.39
	void RTI1516ambassador::enableCallbacks ()
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	// 10.40
	void RTI1516ambassador::disableCallbacks ()
		throw (FederateNotExecutionMember,
		SaveInProgress,
		RestoreInProgress,
		RTIinternalError)
	{ 
		/* TODO */ 
	}

	FederateHandle RTI1516ambassador::decodeFederateHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	ObjectClassHandle RTI1516ambassador::decodeObjectClassHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	InteractionClassHandle RTI1516ambassador::decodeInteractionClassHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	ObjectInstanceHandle RTI1516ambassador::decodeObjectInstanceHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	AttributeHandle RTI1516ambassador::decodeAttributeHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	ParameterHandle RTI1516ambassador::decodeParameterHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	DimensionHandle RTI1516ambassador::decodeDimensionHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	MessageRetractionHandle RTI1516ambassador::decodeMessageRetractionHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}

	RegionHandle RTI1516ambassador::decodeRegionHandle(
		VariableLengthData const & encodedValue) const
	{ 
		/* TODO */ 
		throw RTIinternalError(L"Not yet implemented");
	}




} // end namespace rti1516